pub struct Collection {Show 17 fields
pub banner_image: Option<Media>,
pub blockchain: BlockchainInfo,
pub contract_address: String,
pub created_date: Option<String>,
pub description: Option<String>,
pub featured_image: Option<Media>,
pub floor_price: Option<CurrencyInfo>,
pub hidden: Option<bool>,
pub logo_image: Option<Media>,
pub name: Option<String>,
pub open_sea_collection_verified: Option<bool>,
pub short_description: Option<String>,
pub slug: Option<String>,
pub social_media: Option<Vec<SocialMedia>>,
pub symbol: Option<String>,
pub total_supply: Option<i64>,
pub urls: Option<Vec<Url>>,
}Fields
blockchain: BlockchainInfocontract_address: StringAddress of the contract that minted this NFT.
created_date: Option<String>Timestamp of creation of this contract in RFC 3339.
description: Option<String>featured_image: Option<Media>floor_price: Option<CurrencyInfo>When the value is true, it indicates that this collection, or the collection this NFT belongs to, has been hidden on OpenSea.
logo_image: Option<Media>name: Option<String>open_sea_collection_verified: Option<bool>Whether or not the collection is verified on OpenSea.
short_description: Option<String>slug: Option<String>symbol: Option<String>total_supply: Option<i64>Number of unique tokens in the collection.
urls: Option<Vec<Url>>Trait Implementations
Sourceimpl Debug for Collection
impl Debug for Collection
Sourceimpl<'de> Deserialize<'de> for Collection
impl<'de> Deserialize<'de> for Collection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for Collection
impl Display for Collection